// *******************************************
// Copyright (C) 2004-2011 by LTT GmbH
//
// FILE:      ltt2api.h
//
// DESCR:     LTT2API - Header
//
// AUTHOR:    STK <stefan.knorr@tasler.de>
//
// VERSION:   2.2.x
//
// *******************************************


#ifndef __LTT2API_H__
#define __LTT2API_H__

#include <lttosal.h>
#include <lttosal_time.h>

#include <ltt2api_export.h>

#ifdef __cplusplus
extern "C" {
#endif


// samplerate:
enum LTT_TB_ExternalClock {
  LTT_EXTCLOCK_16BIT                = 0x00000000,
  LTT_EXTCLOCK_15BIT                = 0x00000001,
  LTT_EXTCLOCK_14BIT                = 0x00000002,
  LTT_EXTCLOCK_12BIT                = 0x00000003
};

enum LTT_TB_Flags {
  LTT_SMPLTIME_FLAG_ABOVE           = 0x0000000,
  LTT_SMPLTIME_FLAG_BELOW           = 0x0000001,
  LTT_SMPLTIME_FLAG_CALIB           = 0x0001000,

  LTT_TIMEBASE_MASK                 = 0x0FFFFFFF,
  LTT_TIMEBASE_SLAVEMODE            = 0x10000000,
  LTT_TIMEBASE_MODE_MASK            = 0xF0000000
};


// transfer:
enum LTT_TransferMode {
  LTT_TRANSFER_BLOCKED              = 0x0000,
  LTT_TRANSFER_NONEBLOCKED          = 0x0001,
  LTT_TRANSFER_CONTINUOUS           = 0x0004,
  LTT_TRANSFER_HIGHPRECISION        = 0x0008
};


// trigger:
enum LTT_TriggerMode {
  LTT_TRIG_MODE_LEVEL               = 0x0000,
  LTT_TRIG_MODE_COMPARISION         = 0x0001,
  LTT_TRIG_MODE_REGION              = 0x0002,
  LTT_TRIG_MODE_LEVEL_DELTA         = 0x0004
};

enum LTT_TriggerType {
  LTT_TRIG_TYPE_SINGLE              = 0x0000,
  LTT_TRIG_TYPE_TRIGTIMER           = 0x0001,
  LTT_TRIG_TYPE_MISSING_EVENT       = 0x0002,
  LTT_TRIG_TYPE_ABA_MODE            = 0x0010
};

enum LTT_TriggerSlope {
  LTT_TRIG_SLOPE_POS                = 0x0000,
  LTT_TRIG_SLOPE_NEG                = 0x0001,
  LTT_TRIG_COMP_BIGGER              = LTT_TRIG_SLOPE_POS,
  LTT_TRIG_COMP_SMALLER             = LTT_TRIG_SLOPE_NEG,
  LTT_TRIG_REGION_ENTER             = LTT_TRIG_SLOPE_POS,
  LTT_TRIG_REGION_EXIT              = LTT_TRIG_SLOPE_NEG
};

// channels:
enum LTT_ChannelType {
  LTT_CHNL_TYPE_ANALOG              = 0x0000,
  LTT_CHNL_TYPE_DIGITAL             = 0x0001,
  LTT_CHNL_TYPE_RPM                 = 0x0002
};

enum LTT_ChannelIDBit {
  LTT_CHNL_IDBIT_ANALOG             = 0x0000,
  LTT_CHNL_IDBIT_DIGITAL            = 0x1000,
  LTT_CHNL_IDBIT_RPM                = 0x2000
};

enum LTT_ChannelCoupling {
  LTT_CHNL_AMPTYPE_GND              = 0x0000,
  LTT_CHNL_AMPTYPE_SE_DC_PLUS       = 0x0001,
  LTT_CHNL_AMPTYPE_SE_DC_MINUS      = 0x0002,
  LTT_CHNL_AMPTYPE_DE_DC            = 0x0003,
  LTT_CHNL_AMPTYPE_SE_AC_PLUS       = 0x0004,
  LTT_CHNL_AMPTYPE_SE_AC_MINUS      = 0x0005,
  LTT_CHNL_AMPTYPE_DE_AC            = 0x0006,
  LTT_CHNL_AMPTYPE_SE_DC_PLUS_1M    = 0x0007,
  LTT_CHNL_AMPTYPE_SE_DC_MINUS_1M   = 0x0008,
  LTT_CHNL_AMPTYPE_DE_DC_1M         = 0x0009,

  LTT_CHNL_AMPTYPE_DMS_GND          = 0x0010,
  LTT_CHNL_AMPTYPE_DMS_VDC          = 0x0011,
  LTT_CHNL_AMPTYPE_DMS_VAC          = 0x0012,
  LTT_CHNL_AMPTYPE_DMS_ICP          = 0x0013,
  LTT_CHNL_AMPTYPE_DMS_FULL         = 0x0014,
  LTT_CHNL_AMPTYPE_DMS_HALF         = 0x0015,
  LTT_CHNL_AMPTYPE_DMS_ZERO         = 0x0016,
  LTT_CHNL_AMPTYPE_DMS_FULL_CAL     = 0x0017,
  LTT_CHNL_AMPTYPE_DMS_HALF_CAL     = 0x0018,
  LTT_CHNL_AMPTYPE_DMS_CURRENT      = 0x0019,
  LTT_CHNL_AMPTYPE_DMS_QTR          = 0x001A,
  LTT_CHNL_AMPTYPE_DMS_QTR_CAL      = 0x001B,
  LTT_CHNL_AMPTYPE_DMS_FULL_INV     = 0x0114,
  LTT_CHNL_AMPTYPE_DMS_HALF_INV     = 0x0115,
  LTT_CHNL_AMPTYPE_DMS_QTR_INV      = 0x011A
};

enum LTT_ChannelImpedance {
  LTT_CHNL_IMPEDANCE_POS            = 0x0000,
  LTT_CHNL_IMPEDANCE_NEG            = 0x0001,
  LTT_CHNL_IMPEDANCE_DIFF           = 0x0002,
  LTT_CHNL_IMPEDANCE_INFINTE        = 1000000000
};

enum LTT_ChannelState {
  LTT_CHNL_OFF                      = 0x0000,
  LTT_CHNL_NORMAL                   = 0x0001,
  LTT_CHNL_RAWDATA                  = 0x0002
};


enum LTT_FilterMode {
  LTT_FILTER_OFF                    = 0x0000,
  LTT_FILTER_ON                     = 0x0001
};

enum LTT_FilterType {
  LTT_FILT_TYPE_BUTTERWORTH         = 0x0000,
  LTT_FILT_TYPE_BESSEL              = 0x0002,
  LTT_FILT_TYPE_CHEBYCHEV           = 0x0004,
  LTT_FILT_TYPE_USERDEFINED         = 0x0006,
  LTT_FILT_TYPE_MASK                = 0x000E
};

enum LTT_FilterPol {
  LTT_FILT_POL_TWO                  = 0x0000,
  LTT_FILT_POL_FOUR                 = 0x0010,
  LTT_FILT_POL_SIX                  = 0x0020,
  LTT_FILT_POL_EIGHT                = 0x0030,
  LTT_FILT_POL_TEN                  = 0x0040,
  LTT_FILT_POL_TWELVE               = 0x0050,
  LTT_FILT_POL_FOURTEEN             = 0x0060,
  LTT_FILT_POL_SIXTEEN              = 0x0070,
  LTT_FILT_POL_MASK                 = 0x00F0
};


enum LTT_DeviceOptions {
  LTT_OPT_ODD_PRETRIGGER            = 0x0040,
  LTT_OPT_FRONT_SYNC                = 0x0200,
  LTT_OPT_180_BANDWIDTH_100K        = 0x0800,
  LTT_OPT_TIMEBASE_2500KHZ          = 0x2000,
  LTT_OPT_DMSTYPE_DMS2              = 0x8000
};

#define LTT_ORDER_FRONT_FLAGS(x)    ( ( (x)       ) & 0x0000FFFF )
#define LTT_ORDER_BACK_FLAGS(x)     ( ( (x) >> 16 ) & 0x0000FFFF )

enum LTT_DeviceCalibStatus {
  LTT_CALIB_UNCALIBRATED            = 0x0000,
  LTT_CALIB_CALIBRATED              = 0x0001,
  LTT_CALIB_CERTIFIED               = 0x0010,
  LTT_CALIB_STATUSMASK              = 0x00FF
};

enum LTT_CascadingMode {
  LTT_CASCADE_MODE_NONE            = 0x00,
  LTT_CASCADE_MODE_START           = 0x01,
  LTT_CASCADE_MODE_START_CLOCK     = 0x02,
  LTT_CASCADE_MODE_MASK            = 0x0F,

  LTT_CASCADE_FLAG_SYNCED          = 0x10
};


typedef struct _LTTDEVICEINFO {
  unsigned long lDeviceType;
  unsigned long lSerialNumber;
  unsigned long lFirmware;
  unsigned long lFirmwareBuild;
  unsigned long lChannels;
  unsigned long lOption;
  unsigned long lMOhm;
  unsigned long lICP;
  // calibration info
  float calib_temperature;
  unsigned long calib_status;
  OSALLocalTime calib_time;
  char p_calib_certified_name[256];
  // additional device info
  unsigned long frame_serial;
  unsigned long order_flags;
  unsigned long memory;
  float range_corr;
  // internal HD
  int64_t hd_capacity;
  // reserved
  unsigned long p_reserved[10];
} LTTDeviceInfo;


typedef struct __TTRIGGERPARAM {
  unsigned long active;
  unsigned long type;
  unsigned long slope;
  unsigned long channel;
  unsigned long channel_type;
  float p_para[2];
  unsigned long scan_field;
  unsigned long pre_trigger;
  unsigned long trig_timer;
} LTTTriggerParam;


typedef struct __TDATAPARAM {
  short *p_data;
  unsigned long buffer_len;
} LTTDataParam;


typedef struct __LTTCHANNELPARAM {
  unsigned long chnl_id;
  unsigned long active;
  unsigned long range;
  unsigned long coupling;
  unsigned long dmspower;
  long dmsoffset;
  /*
  char p_name[32];
  char p_signature[32];
  char p_unit[32];
  float usr_scale;
  float usr_offset;
  // channel impedance
  unsigned long imp_pos;
  unsigned long imp_neg;
  unsigned long imp_diff;
  */
} LTTChannelParam;


typedef struct __LTTFILTERPARAM {
  long active;
  long cutoff_timebase;
  long p_reserved[8];
} LTTFilterParam;


typedef struct __LTTPARAM {
  long xfer_infinite;
  int64_t l_datalength;
  unsigned long seqlength;
  unsigned long timebase;
  unsigned long analog_cnt;
  unsigned long digital_cnt;
  unsigned long rpm_cnt;
  LTTDataParam data;
  LTTTriggerParam trigger;
  LTTFilterParam filter;
  LTTChannelParam *p_analog;
  LTTChannelParam *p_digital;
  LTTChannelParam *p_rpm;
} LTTParam;


typedef struct __LTTDMSOFFSET {
  short offset_dac;
  short offset;
} LTTDMSOffset;


typedef struct __LTTRECORDDEVINFO {
  unsigned long dev_idx;
  unsigned long dev_serial;
  unsigned long recorded;
  uint64_t xfer_hd_seq_cnt;
  unsigned long hd_use_button;
  unsigned long hd_timebase;
  OSALLocalTime upload_time;
  unsigned long md5sum_valid;
  unsigned char p_md5sum[ 16 ];
  unsigned long rec_dev_cnt;
  unsigned long p_rec_devorder[ 4 ];
  unsigned long hd_dev_seq_len;
  unsigned long hd_ext_info_size;
} LTTRecordDevInfo;


typedef struct __LTTRECORDDEVINFOLIST {
  unsigned long info_cnt;
  LTTRecordDevInfo p_info[ 16 ];
} LTTRecordDevInfoList;


typedef struct __LTTRECORDINFO {
  unsigned long min_info_cnt;
  unsigned long dev_match;
  unsigned long p_info_match[ 16 ];
  unsigned long dev_cnt;
  LTTRecordDevInfoList p_devinfo[ 4 ];
} LTTRecordInfo;

/***************************************
 ***************************************
 *  STDCALL
 ***************************************
 ***************************************/

//========================================
//  LTT2API-MAIN
//========================================

/*****************************************

  FUNCTION: LTTInit

  DESCR.:   Initialize internal resource
              and searches for LTT-devices

  INPUT:    p_analog_cnt:
                give back amount of
                available analog
                channels

              p_digital_cnt:
                give back amount of
                available digiatl
                channels

              p_rpm_cnt:
                give back amount of
                available RPM
                channels

              p_digio_cnt:
                give back amount of
                available DIG-IO
                channels

  OUTPUT:   

*****************************************/
__LTT2API_IMP long __APIDEC LTTInit( long *p_analog_cnt,
                                     long *p_digital_cnt,
                                     long *p_rpm_cnt,
                                     long *p_digio_cnt );


/*****************************************

  FUNCTION: LTTDeInit

  DESCR.:   Shut down internal resources

  INPUT:    None

  OUTPUT:   None

*****************************************/
__LTT2API_IMP void __APIDEC LTTDeInit( void );



/*****************************************

  FUNCTION: LTTResetParamter

  DESCR.:   Reset parameter settings for
              LTT devices

  INPUT:

  OUTPUT:   

*****************************************/
__LTT2API_IMP void __APIDEC LTTResetParameter( long mode );


/*****************************************

  FUNCTION: LTTConnectDevices

  DESCR.:   Open device handles

  INPUT:    None

  OUTPUT:   None

*****************************************/
__LTT2API_IMP void __APIDEC LTTConnectDevices( void );


/*****************************************

  FUNCTION: LTTReleaseDevices

  DESCR.:   Close device handles

  INPUT:    None

  OUTPUT:   None

*****************************************/
__LTT2API_IMP void __APIDEC LTTReleaseDevices( void );


/*****************************************

  FUNCTION: LTTCascadingMode

  DESCR.:   Specifies how multiple LTT devices
            will work together. Independently or
            in cascading mode.

  INPUT:    mode:
                specifies whether multiple
                LTT devices are running
                cascaded or independent
                but still with the same
                timebase

                  0x00 - independent mode
                  0x01 - meas. start
                         synchronised
                  0x02 - meas. start and clock
                         synchronised
                      
                Flags:
                  0x10 - device stack is externally
                         synchronised

  OUTPUT:   None

*****************************************/
__LTT2API_IMP void __APIDEC LTTCascadingMode( long mode );


/*****************************************

  FUNCTION: LTTMasterCorrectionMode

  DESCR.:   Corrects Master-Slave sample
              divergence.

  INPUT:    mode:
                switch correction on/off

                  0 - OFF
                  1 - ON

  OUTPUT:   None

*****************************************/
__LTT2API_IMP void __APIDEC LTTMasterCorrectionMode( long mode );


/*****************************************

  FUNCTION: LTTSyncCorrection

  DESCR.:   Omits sequencences at measurement
              start

  INPUT:    corr:
                omit 'corr' sequences

  OUTPUT:   None

*****************************************/
__LTT2API_IMP void __APIDEC LTTSyncCorrection( long corr );


/*****************************************

  FUNCTION: LTTSetTransferMode

  DESCR.:   Changes OSAL transfer subsystem.
              Must be called before LTTInit()

  INPUT:    type:
                transfer subsystem

                  1 - new SCSI-PD
                  2 - old SCSI-SPT
                  3 - NETROA

              p_local:
                pointer to IP-address string
                of local network adapter

              p_netmask:
                pointer to IP-subnetmask string

              p_remote:
                pointer to IP-address string
                of remote LTTROAD-system,
                to which LTT2API should
                connect

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTSetTransferMode( long type,
                                                const char *p_local,
                                                const char *p_netmask,
                                                const char *p_remote );


/*****************************************

  FUNCTION: LTTSetDeviceOrder

  DESCR.:   Set a device order.
            If device-order doesn't match
            the devices found, it will be 
            ignored

            CAUTION:
            Must be called before LTTInit()

  INPUT:    dev_cnt:
                device-count
                [0..3]

            p_devorder:
                pointer to list with serial
                numbers

  OUTPUT:     0 - Everything OK
             -1 - invalid pointer
             -2 - device-count out-of-range

*****************************************/
__LTT2API_IMP long __APIDEC LTTSetDeviceOrder(  unsigned long dev_cnt, 
                                                const unsigned long *p_devorder );



//== NET-ROA =============================

/*****************************************

  FUNCTION: LTTNetRoa_Scan

  DESCR.:   Scans network for available
            NER-ROA clients with LTT-devices

  INPUT:    p_local:
                pointer to IP-address string
                of local network adapter

            p_netmask:
              pointer to IP-subnetmask string

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTNetRoa_Scan( const char *p_local,
                                            const char *p_netmask );


/*****************************************

  FUNCTION: LTTNetRoa_GetScanAddress

  DESCR.:

  INPUT:    scan_idx:
                index in scanlist

            p_addr:
              pointer to string where
              IP-address  will be stored.

              Application must provide at
              least 32 Bytes

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTNetRoa_GetScanAddress( unsigned long scan_idx,
                                                      char *p_addr );



//== UPLOAD ==============================

/*****************************************

  FUNCTION: LTTUploadParameters

  DESCR.:   Checks, if current paramter
              settings are correct and
              if yes, uploads them to
              LTT-devices.

  INPUT:    None

  OUTPUT:   The returnede error code can
            be a sum of single error:

              0 - Everything OK
             -1 - no devices present
             -2 - Wrong sample rate by current
                  channel setting
             -4 - No channels active
             -8 - transfer active
            -16 - Wrong channel combination!!
                  When backside channels used,
                  at least one front channel must
                  be active also!
            -32 - Trigger channel not active
            -64 - PRE-Trigger settings wrong
           -256 - PRE-Trigger settings wrong
           -512 - No Buffer settings specified!!
          -1024 - master is not active (internal error)
          -2048 - filter cut-off frequency out fo range

*****************************************/
__LTT2API_IMP long __APIDEC LTTUploadParameters( void );


/*****************************************

  FUNCTION: LTTGetParameters

  DESCR.:   Gets current valid setup

  INPUT:
              p_para:
                Pointer to data-structure, where
                current setup-parameters will be
                stored.

  OUTPUT:     0 - Everything OK
             -1 - invalid pointer

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetParameters( LTTParam *p_para );


//== STAND-ALONE =========================
/*****************************************

  FUNCTION: LTTHDClearAll

  DESCR.:   Clear's all record-setups from HD.

  INPUT:    None
  
  OUTPUT:   0 - OK

*****************************************/
__LTT2API_IMP long __APIDEC LTTHDClearAll();


/*****************************************

  FUNCTION: LTTHDClearAllPending

  DESCR.:   Clear's all not record-setups
            from HD.

  INPUT:    None
  
  OUTPUT:   0 - OK

*****************************************/
__LTT2API_IMP long __APIDEC LTTHDClearAllPending();


/*****************************************

  FUNCTION: LTTHDResetSetupRecorded

  DESCR.:   Resets setup on HD for 
            re-recording

  INPUT:    rec_idx:
              index of setup

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTHDResetSetupRecorded( unsigned long rec_idx );


/*****************************************

  FUNCTION: LTTHDAppendSetup

  DESCR.:   Appends setup to HD.

  INPUT:    None
  
  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTHDAppendSetup( const char *p_info, unsigned long info_size );


/*****************************************

  FUNCTION: LTTHDRecordReplay

  DESCR.:   Switches API to REPLAY-mode
            and transfers on internal HD's
            recorded measurements

  INPUT:

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTHDRecordReplay( unsigned long rec_idx, char *p_info, unsigned long info_max_size );


/*****************************************

  FUNCTION: LTTHDRecordReplaySetPos

  DESCR.:   Sets position for data-replay

  INPUT:    seq_pos:
              sequence position

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTHDRecordReplaySetPos( uint64_t seq_pos );


/*****************************************

  FUNCTION: LTTHDRecordLeaveReplay

  DESCR.:   Switches API to ONLIONE-mode.

  INPUT:

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTHDRecordLeaveReplay();


//== MEASUREMENT =========================

/*****************************************

  FUNCTION: LTTStart

  DESCR.:   Starts LTT-device and activates
              Trigger (if set)

  INPUT:    None

  OUTPUT:     0 - everything's OK
             -1 - no devices present or
                  no active channels

*****************************************/
__LTT2API_IMP long __APIDEC LTTStart( void );

/*****************************************

  FUNCTION: LTTStop

  DESCR.:   Stops the data aquisition
              at LTT device.

  INPUT:    None

  OUTPUT:   None

*****************************************/
__LTT2API_IMP void __APIDEC LTTStop( void );


/*****************************************

  FUNCTION: LTTCheckTrigger

  DESCR.:   Checks if the trigger has been
              fulfilled.

              In the case the trigger is still
              active, the call waits the specified
              amount of time before the call
              returns.

  INPUT:    MilliSecond:
                amount of time to wait
                after negative trigger
                result

  OUTPUT:     0 - Trigger active
              1 - Trigger successful

*****************************************/
__LTT2API_IMP long __APIDEC LTTCheckTrigger( unsigned long MilliSecond );



//== CALIBRATION =========================

/*****************************************

  FUNCTION: LTTGetCalibTemperature

  DESCR.:   gives back internal temperature
              of specified device at last
              calibration

  INPUT:    dev_idx:
                Device index

  OUTPUT:   internal devices temperature
            in degrees C

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetCalibTemperature( unsigned long dev_idx );



//== TEMPERATUR ==========================

/*****************************************

  FUNCTION: LTTGetTemperature

  DESCR.:   measures temperature in specified
              device

  INPUT:    dev_idx:
                Device index

  OUTPUT:   current internal devices
            temperature

*****************************************/
__LTT2API_IMP float __APIDEC  LTTGetTemperature( unsigned long dev_idx );



//=== DATA-INFO ==========================

/*****************************************

  FUNCTION: LTTGetDLLInfo

  DESCR.:   gives back identification
              string of DLL

  INPUT:    p_buffer:
                pointer to char-field;
                minimum size: 64 Bytes!

  OUTPUT:     0 allways

*****************************************/
__LTT2API_IMP long __APIDEC   LTTGetDLLInfo( char *p_buffer );


/********************************************
  FUNCTION: LTTGetVersion

  DESCR.:   gives back LTT2API version

  INPUT:    None

  OUTPUT:   coded version

 ********************************************/
__LTT2API_IMP long __APIDEC LTTGetVersion( void );


/*****************************************

  FUNCTION: LTTGetDeviceInfo

  DESCR.:   gives back identification
              string of specified device

  INPUT:    dev_idx:
                Device index

              p_buffer:
                pointer to char-field;
                minimum size: 64 Bytes!

  OUTPUT:     >0 - number of analog channels of
                   the device
              -1 - device not found

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetDeviceInfo( unsigned long dev_idx,
                                              char *p_buffer );


/*****************************************

  FUNCTION: LTTGetDeviceInfoEx

  DESCR.:   gives back identification
              string of specified device

  INPUT:    dev_idx:
                Device index

              p_devinfo:
                pointer to LTTDeviceInfo
                structure

  OUTPUT:     0 - everything's OK
             -1 - device not found

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetDeviceInfoEx( unsigned long dev_idx,
                                                LTTDeviceInfo *p_devinfo );


/*****************************************

  FUNCTION: LTTGetDevices

  DESCR.:   gives back number of LTT
              devices found

  INPUT:    None

  OUTPUT:   number of LTT devices found

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetDevices( void );


/*****************************************

  FUNCTION: LTTChannel2Device

  DESCR.:   Returns device index of channel

  INPUT:    ch_idx:
                channel index

              ch_type:
                type of channel

  OUTPUT:  device index

*****************************************/
__LTT2API_IMP long __APIDEC LTTChannel2Device( unsigned long ch_idx,
                                               unsigned long ch_type );


/*****************************************

  FUNCTION: LTTChannelAtDevice

  DESCR.:   Returns channel index at device
            of channel

  INPUT:    ch_idx:
              channel index

            ch_type:
              type of channel

  OUTPUT:  device channel index

*****************************************/
__LTT2API_IMP long __APIDEC LTTChannelAtDevice( unsigned long ch_idx,
                                                unsigned long ch_type );


/*****************************************

  FUNCTION: LTTDevice2Channel

  DESCR.:   Returns channel index of device
            index and device channel index.

  INPUT:    dev_idx:
              device index

            dev_ch_idx:
              device channel index

            dev_ch_type:
              channel type

  OUTPUT:   >=0 - channel index
             -1 - invalid channel type
             -2 - invalid device index
             -3 - invalid device channel index

*****************************************/
__LTT2API_IMP long __APIDEC LTTDevice2Channel( unsigned long dev_idx,
                                               unsigned long dev_ch_idx,
                                               unsigned long dev_ch_type );


//========================================
//  LTT2API-TRIGGER
//========================================

/*****************************************

  FUNCTION: LTTTrigger

  DESCR.:   Enables/Disables trigger channel and
              sets trigger parameters

  INPUT:    Trig:
                0 - Trigger OFF
                1 - Trigger ON

              Slope:
                Level, Comparison + Delta:
                  0 - positive slope
                  1 - negative slope
                Comparison:
                  0 - bigger then threshold
                  1 - smaller then threshold
                Region:
                  0 - enter region
                  1 - exit region

              Channel:
                Trigger channel index
                starting with 0

              ChType:
                0 - analog channel
                1 - digital channel

              TrigType:
                Analog:
                  0 - Level
                  1 - Comparison
                  2 - Region
                  4 - Comparison + Delta
                Digital:
                  0 - Single Bit mode

              f1:
                Level, Comparison, Comparison + Delta:
                  Threshhold  [% FSR]
                Region:
                  Lower Threshhold  [% FSR]
                Digital:
                  Trigger-Bit

              f2:
                Level:
                  Sensitivity [% FSR]
                Region:
                  Upper Threshhold [% FSR]
                Comparison + Delta:
                  min. difference to previous sample [% FSR]
                Comparison, Digital:
                  not used

  OUTPUT:     0 - OK
             -1 - invalid channel index
             -2 - level trigger:
                  can't have negative hysterisis.
             -3 - delta trigger:
                  invalid range for x2 ( 0 < x2 < 6 ).
             -4 - level+delta trigger:
                  invalid range for x2 ( 0 < x2 ).
             -5 - invalid digital trigger bit(s)
                  FW  6xx ( 0 or 7 < Channel < 16)
                  FW >700 ( 0 or 9 < Channel < 16)
             -6 - invalid trigger channel type
             -7 - invalid trigger type


*****************************************/
__LTT2API_IMP long __APIDEC LTTTrigger( unsigned long Trig,
                                        unsigned long Slope,
                                        unsigned long Channel,
                                        unsigned long ChType,
                                        unsigned long TrigType,
                                        float f1,
                                        float f2 );


/*****************************************

  DESCR.:   Set PRE-Trigger part of signal.

              The pretrigger length is limited by
              60 Megasamples (120*1024*1024 byte).
              So with 6 active channels the maximum
              pretrigger per channel is 10 Megasamples.

  INPUT:    pre_triglen:
                Amount of pre-tigger
                samples [kS]

              pre_sampletime:
                Sample time in [ns] before
                trigger has happened.

                CAUTION:
                Not all times are allowed.

                0 - use no different sampletime

  OUTPUT:     0 - OK
             -1 - No trigger active
             -2 - Wrong PRE-trigger length

*****************************************/
__LTT2API_IMP long __APIDEC LTTTrigger_SetPreTrigger( unsigned long pre_triglen,
                                                      unsigned long pre_sampletime );


/*****************************************

  FUNCTION: LTTTrigger_GetPreTriggerLimit

  DESCR.:   Get maximum allowed 
              PRE-Trigger length.

  INPUT:    
  
  OUTPUT:   maximum PRE-trigger 
            length [KS/ch]

*****************************************/
__LTT2API_IMP unsigned long __APIDEC LTTTrigger_GetPreTriggerLimit();


/*****************************************

  FUNCTION: LTTTrigger_SetReactivationTime

  DESCR.:   Sets trigger reactivation time. after timer
              has expired trigger will be reactivated.
              This can result in multiple trigger
              events in data stream with no direct
              time correlation.

  INPUT:    react_time:
                Time after which the trigger
                will be reactivated
                automatically [ns]
                allowed values:
                0         - No trigger timer
                100ns..1s - allowed range

  OUTPUT:     0 - OK
             -1 - no trigger active;
             -2 - reactivation time too big;

*****************************************/
__LTT2API_IMP long __APIDEC LTTTrigger_SetReactivationTime( unsigned long react_time );


/*****************************************

  FUNCTION: LTTTrigger_SetABAMode

  DESCR.:   Sets trigger in ABA mode

  INPUT:    aba_btime:
                Time after which the device
                changes back to PRE-Trigger
                sampletime;
                the upper limit depends on
                the firmware version;
                allowed values:
                0            - No trigger timer
                100ns..limit - allowed range;
                               limit >= 250ms

              aba_sampletime:
                Sample time in [ns] before
                trigger has happened and to
                which is switched back after
                timer has expired.

                CAUTION:
                Not all times are allowed.

  OUTPUT:     0 - OK
             -1 - no trigger active;
             -2 - time for B-Mode too big;
             -3 - feature not supported by firmware

*****************************************/
__LTT2API_IMP long __APIDEC LTTTrigger_SetABAMode( unsigned long aba_btime,
                                                   unsigned long aba_sampletime );


/*****************************************

  FUNCTION: LTTTriggerScan

  DESCR.:   Sets OR-Scantrigger on analog
              channels. is limited to a device.
              inter-device scantrigger is not
              possible !!

  INPUT:    scan_channels:
                Bit-Field, which channels should be scaned
                for active trigger.
                CAUTION:
                Cannot be used in conjunction with ABA-Mode
                and Reactivation-Timer.

  OUTPUT:     0 - OK

*****************************************/
__LTT2API_IMP long __APIDEC LTTTriggerScan( unsigned long scan_channels );


//========================================
//  LTT2API-CHANNELS
//========================================

/*****************************************

  FUNCTION: LTTAnalogChannel

  DESCR.:   Turns on/off analog channels on
            standard hardware LTT-184/186 and
            apply the channel settings

  INPUT:    ch_idx:
              LTT channel index starting
              with 0

            active:
              0 - channel OFF
              1 - channel ON
              2 - channel RAW

            range:
              channel range specified in [mV].
              Allowed settings:
                [  1000,   2000,   2500,   5000,
                  10000,  20000,  25000,  50000,
                 100000, 200000, 250000, 500000]

            coup:
              0 - GND
              1 - DC, Single ended +
              2 - DC, Single ended -
              3 - DC, Differential ended
              4 - AC, Single ended +
              5 - AC, Single ended -
              6 - AC, Differential ended
              7 - 1MOhm, DC, Single ended +
              8 - 1MOhm, DC, Single ended -
              9 - 1MOhm, DC, Differential ended

            ioc_offset:
              integer value which is calculated by IOC
              (Internal Offset Compensation)
              0 normaly


  OUTPUT:     0  if successful
             -1  if channel doesn't exist
             -2  invalid coup
             -3  coup doesn't match LTT-Hardware
             -4  channel range doesn't match coup settings

*****************************************/
__LTT2API_IMP long __APIDEC LTTAnalogChannel( unsigned long ch_idx,
                                              unsigned long active,
                                              unsigned long range,
                                              unsigned long coup,
                                              long ioc_offset );


/*****************************************

  FUNCTION: LTTAnalogDMSChannel

  DESCR.:   Turns on/off analog channels
            on DMS-hardware LTT-180/182 and
            apply the channel settings.

  INPUT:    ch_idx:
              LTT channel index starting
              with 0

            active:
              0 - channel OFF
              1 - channel ON
              2 - channel RAW

            dms_range:
              channel range specified in [mV].
              Allowed settings VOLT/GND:
                [ 125, 250, 500, 1000, 2000, 5000, 10000 ]
              Allowed settings DMS:
                [ 1, 2, 5, 10, 20, 50, 100, 200, 500 ]

            dms_coup:
              16 - GND
              17 - Volt DC
              18 - Volt AC
              19 - Volt ICP
              20 - DMS Fullbridge
              21 - DMS Half-/Quarterbridge
              22 - DMS Zero
              23 - DMS Fullbridge Cal
              24 - DMS Half-/Quarterbridge Cal
              25 - DMS Current

            dms_power:
              channel power supply specified in [mV]
              Allowed settings on DMS:
                [ 0, 1000, 2000, 5000, 10000, 15000 ]
              Allowed settings on DMS Current:
                [    0,  500, 1000, 1500, 2000, 2500,
                  3000, 3500, 4000, 4500, 5000, 5500,
                  6000, 6500, 7000, 7500, 8000, 8500,
                  9000, 9500, 10000 ]

            dms_offset:
              integer value which is calculated by AutoZero
              0 normaly

  OUTPUT:     0  if successful
             -1  channel doesn't exist
             -2  invalid dms_coup
             -3  dms_coup doesn't match LTT-Hardware
             -4  channel dms_range doesn't match dms_coup settings
            -12  device doesn't support DMS

*****************************************/
__LTT2API_IMP long __APIDEC LTTAnalogDMSChannel( unsigned long ch_idx,
                                                 unsigned long active,
                                                 unsigned long dms_range,
                                                 unsigned long dms_coup,
                                                 unsigned long dms_power,
                                                 long dms_offset );


/*****************************************

  FUNCTION: LTTDigitalChannel

  DESCR.:   Turns on/off digital channels

  INPUT:    ch_idx:
                channel ID, which to be modified.

              active:
                0 - channel OFF
                1 - channel ON

  OUTPUT:      0  if successful
              -1  if channel doesn't exist.

*****************************************/
__LTT2API_IMP long __APIDEC LTTDigitalChannel( unsigned long ch_idx,
                                               unsigned long active );


/*****************************************

  FUNCTION: LTTRPMChannel

  DESCR.:   Turns on/off RPM channels

            CAUTION:
            Only the RPM-channel at the master
            device per device stack is supported.

  INPUT:    ch_idx:
              channel ID, which to be modified.
              Must be 0 !!

            active:
              0 - channel OFF
              1 - channel ON

  OUTPUT:      0  if successful
              -1  if channel doesn't exist.

*****************************************/
__LTT2API_IMP long __APIDEC LTTRPMChannel( unsigned long ch_idx,
                                           unsigned long active );



/*****************************************

  FUNCTION: LTTOutputImpedance

  DESCR.:   Sets output impedance of signal source
            for specified input coupling.

  INPUT:    ch_idx
              Analog channel index

            conn_type:
              type of input coupling:
                0 - SE+ coupling
                1 - SE- coupling
                2 - DE  coupling

            impedance:
              impedance value in [Ohm];
              values > 1000000000 --> infinite

  OUTPUT:     0  if successful
             -1  if channel doesn't exist
             -2  invalid connection type

*****************************************/
__LTT2API_IMP  long __APIDEC LTTOutputImpedance( unsigned long ch_idx,
                                                 unsigned long conn_type,
                                                 unsigned long impedance );


/*****************************************

  FUNCTION: LTTAnalogAutoZero

  DESCR.:   Automatic ReZero of Signal-Level
            for selected active channels
            in current range.
            [LTT-180/182 only]

  INPUT:    chnl_cnt:
              length of channel-list

            p_chnl_list:
              pointer to channel-list for rezero'ing

  OUTPUT:     0 - always

*****************************************/
__LTT2API_IMP long __APIDEC LTTAnalogAutoZero( unsigned long chnl_cnt,
                                               unsigned long *p_chnl_list );


/*****************************************

  FUNCTION: LTTAnalogIOCompensation

  DESCR.:   Internal Offset Compensation
            of GND-Level for selected active 
            channels.
            [LTT-184/186 only]

  INPUT:    chnl_cnt:
              length of channel-list

            p_chnl_list:
              pointer to channel-list for rezero'ing

  OUTPUT:     0 - always

*****************************************/
__LTT2API_IMP long __APIDEC LTTAnalogIOCompensation( unsigned long chnl_cnt,
                                                     unsigned long *p_chnl_list );


/*****************************************

  FUNCTION: LTTSetInternReference

  DESCR.:   Sets all the channels for a given device
            to the internal reference.

  INPUT:    dev_idx:
              Selects the LTT device.

            ref_idx:
              index of reference value table
              0 <=>  GND
              1 <=>  857mV
              2 <=>  3.00V
              3 <=>  Vtemp
              4 <=>  Vtemp ^u 3.00V
              5 <=>  3.00V ^u 3.00V
              6 <=>  0 - 857mV

  OUTPUT:     0  OK
             -1  invalid device index
             -2  invalid reference index

*****************************************/
__LTT2API_IMP long __APIDEC LTTSetInternReference( unsigned long dev_idx,
                                                   unsigned long ref_idx );


/*****************************************

  FUNCTION: LTTGetChannelConverter

  DESCR.:   gives back conversion factor
            for requested channel to
            calculate the voltage value
            from a data sample:

              [V] = [16Bit] * F

  INPUT:    ch_idx:
              Analog channel index

  OUTPUT:   conversion factor

*****************************************/
__LTT2API_IMP double __APIDEC LTTGetChannelConverter( unsigned long ch_idx );


/*****************************************

  FUNCTION: LTTGetChannelRange

  DESCR.:   gives back range for
            requested channel

  INPUT:    ch_idx:
              Analog channel index

  OUTPUT:   maximum range; +/- value in [mV]

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetChannelRange( unsigned long ch_idx );


/*****************************************

  FUNCTION: LTTGetDMSChannelOffset

  DESCR.:   gives back offset of channel

  INPUT:    ch_idx:
                Analog channel index

  OUTPUT:   coded channel offset

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetDMSChannelOffset( unsigned long ch_idx );


/*****************************************

  FUNCTION: LTTGetChannelCouplingListLength

  DESCR.:   gives back length of list of
            supported channel input
            couplings

  INPUT:    dev_idx:
                device index

  OUTPUT:   length of list

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetChannelCouplingListLength( unsigned long dev_idx );


/*****************************************

  FUNCTION: LTTGetChannelCouplingList

  DESCR.:   fills list with supported
            channel input couplings

  INPUT:    p_couplist:
                Pointer to list vector

            dev_idx:
                device index

            coup:
                input coupling

  OUTPUT:     0 - successful
             -1 - invalid pointer

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetChannelCouplingList(  unsigned long *p_couplist,
                                                        unsigned long dev_idx );


/*****************************************

  FUNCTION: LTTGetChannelRangeListLength

  DESCR.:   gives back length of list of
              supported channel-ranges

  INPUT:    dev_idx:
                device index

              coup:
                input coupling

  OUTPUT:   length of list

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetChannelRangeListLength( unsigned long dev_idx,
                                                          unsigned long coup );


/*****************************************

  FUNCTION: LTTGetChannelRangeList

  DESCR.:   fills list with supported
              channel-ranges

  INPUT:    p_rnglist:
                Pointer to list vector

              dev_idx:
                device index

              coup:
                input coupling

  OUTPUT:     0 - successful
             -1 - invalid pointer

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetChannelRangeList( unsigned long *p_rnglist,
                                                    unsigned long dev_idx,
                                                    unsigned long coup );


/*****************************************

  FUNCTION: LTTGetChannelID

  DESCR.:   Get channel-id to indexed channel

  INPUT:    ch_idx:
                channel index; 
                [0..ch_cnt] of requested 
                channel type
                
              ch_type:
                LTT_CHNL_TYPE_ANALOG
                LTT_CHNL_TYPE_DIGITAL
                LTT_CHNL_TYPE_RPM

  OUTPUT:   >=0 - channel-id
             -1 - invalid channel index
             -2 - invalid channel type

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetChannelID( unsigned long ch_idx, 
                                             unsigned long ch_type );


//========================================
//  LTT2API-TIMEBASE
//========================================

/*****************************************

  FUNCTION: LTTSampleTime

  DESCR.:   Sets the sampling time.

  INPUT:    sample_time:
                Sample time in nano-seconds;

                Caution:
                Not all times are allowed.

                Supported sample times depend on the particular
                hardware type.
                You can get a full list of supported sample-times
                from the API.

              NEW:
                  To use devices in slave-mode,
                  the flag 0x1000000 is added to
                  timebase !!

              time_flag:
                If sample time is between two allowed
                sample times, this parameter indicates,
                which of both is choosen for legal
                sample time

                0 - upper sample time
                1 - lower sample time

  OUTPUT:   The actual sampling time used in [ns].

*****************************************/
__LTT2API_IMP long __APIDEC LTTSampleTime( unsigned long sample_time,
                                           long time_flag );


/*****************************************

  FUNCTION: LTTFilter

  DESCR.:   Sets the digital filter.
              A common filter for all channels
              is supported.

  INPUT:    filter_mode:
                A combination of certain flags, which
                specifies the requested digital filter.

                Filter mode [Bit 0]:
                  0 - Filter OFF
                  1 - Filter ON

                Filter types [Bit 1..4]:
                	0 - Butterworth
                	2 - Bessel
                	4 - Chebychev

                Filter pol  [Bit 5..8]:
                	 0 - 2-pol
                	16 - 4-pol
              	  32 - 6-pol

              filter_cutoff:
                Cut-Off frequency of the filter
                (-3dB point)

  OUTPUT:     0 - Everything's OK
             -1 - wrong filter type
             -2 - wrong filter pol

*****************************************/
__LTT2API_IMP long __APIDEC LTTFilter( unsigned long filter_mode,
                                       unsigned long filter_cutoff );

/*****************************************

  FUNCTION: LTTGetResolution

  DESCR.:   gives back resolution at current
              sample rate

  INPUT:    None

  OUTPUT:   resolution in bits

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetResolution( void );


/*****************************************

  FUNCTION: LTTGetSampleTimeListLength

  DESCR.:   gives back length of list of
              supported sample-times

  INPUT:    None

  OUTPUT:   length of list

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetSampleTimeListLength( void );


/*****************************************

  FUNCTION: LTTGetSampleTimeList

  DESCR.:   fills list with supported
              sample-times

  INPUT:    p_list:
                Pointer to list vector

  OUTPUT:     0 - successful
             -1 - invalid pointer

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetSampleTimeList( long *p_list );



//========================================
//  LTT2API-DATA
//========================================

/*****************************************

  FUNCTION: LTTGetRAMBufferSettings

  DESCR.:   Gives back needed buffer size
              in bytes.

  INPUT:    seq_cnt
                Amount of sequences

              seq_len:
                Amount of active channels

  OUTPUT:   The size of the buffer in bytes.

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetRAMBufferSettings( unsigned long seq_cnt,
                                                     unsigned long seq_len );

/*****************************************

  FUNCTION: LTTRAMBufferSettings

  DESCR.:   Setting up the RAM buffer system
              for data transfer

  INPUT:    p_buffer:
                Pointer to RAM-Buffer.

              seq_cnt:
                Amount of sequences;
                must be multiple of 1024

              seq_len:
                Amount of active channels

  OUTPUT:     0 success
             -1 STREAM already set up !!
                RAM and STREAM are exclusive buffer
                settings.
             -2 length per channel is invalid

*****************************************/
__LTT2API_IMP long __APIDEC LTTRAMBufferSettings( short *p_buffer,
                                                  unsigned long seq_cnt,
                                                  unsigned long seq_len );

/*****************************************

  FUNCTION: LTTSTREAMSettings

  DESCR.:   Deprecated

  INPUT:    p_buffer:
                Pointer to RAM-Buffer.

              buf_len:
                Buffer size in samples

              seq_cnt:
                Amount of sequences

              seq_len:
                Amount of active channels

  OUTPUT:    -1 always

*****************************************/
__LTT2API_IMP long __APIDEC LTTSTREAMSettings( short *p_buffer,
                                               unsigned long buf_len,
                                               unsigned long seq_cnt,
                                               unsigned long seq_len );


/*****************************************

  FUNCTION: LTTSTREAMTransfer

  DESCR.:   Activates new stream transfer.

  INPUT:    mode:
                currently not used.

              seq_cnt:
                Number of sequences

  OUTPUT:     0 success
             -1 ERROR: RAM already set up !!
                       RAM and STREAM are exclusive buffer
                       settings.

*****************************************/
__LTT2API_IMP long __APIDEC LTTSTREAMTransfer( long mode,
                                               unsigned long seq_cnt );

/*****************************************

  FUNCTION: LTTBufferReset

  DESCR.:   Resets the essential parameters
              for the buffers.

  INPUT:    None

  OUTPUT:   None

*****************************************/
__LTT2API_IMP void __APIDEC LTTBufferReset( void );


//== STAND-ALONE =========================

/*****************************************

  FUNCTION: LTTHDRecordLength

  DESCR.:   Sets the HD record length.

  INPUT:    dwSamplesPerChannel:
              Number of samples per channel

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTHDRecordLength( uint64_t dwHDSamplesPerChannel );


/*****************************************

  FUNCTION: LTTHDRecordButton

  DESCR.:   Sets the HD button before to
            activate measurement.

  INPUT:    use_button:
              0 - no button (default)
              1 - use button

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTHDRecordButton( unsigned long use_button );


/*****************************************

  FUNCTION: LTTHDGetRecordInfo

  DESCR.:   Sets the HD record length.

  INPUT:    p_recinfo:
              pointer to Record-Info

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTHDGetRecordInfo( LTTRecordInfo *p_recinfo );


/*****************************************

  FUNCTION: LTTHDGetRecordParameter

  DESCR.:   Gets the HD record-parameter

  INPUT:    rec_idx:
              record-info index
            
            p_para:
              pointer to LTTParam

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTHDGetRecordParameter( unsigned long rec_idx, 
                                                     LTTParam *p_para,
                                                     char *p_info,
                                                     unsigned long info_max_size );



//== DATA-TRANSFER =======================

/*****************************************

  FUNCTION: LTTTransfer2Buffers

  DESCR.:   Transfers the data from the devices
              to the assigned buffers.
              This call initiates the real transfer.
              The transfer can work in BLOCKED or
              NONE_BLOCKED mode.

              BLOCKED:
              The call returns, when the transfer is
              done. This is not possible with the
              STREAM buffer system.

              NONE_BLOCKED:
              The transfer is initiated and the call
              returns immediately. The Transfer must be
              monitored with LTTDataTransferStatus.

  INPUT:    BufferType:
                Currently ignored!

              BlockMode:
                0 - Blocked mode;
                    Call returns, when data are in buffer.
                1 - NON-Blocked mode;
                    Call initiate transfer and
                    returns immediately.
                    End of transfer can be obtained
                    with LTTDataTransferStatus()

                Some flags can be applied to the mode:

                4 - Continuous transfer;
                    For subsequent calls of LTTTransfer2Buffers()
                    a restart of the LTT-systems is not done.
                    This is necessary for infinite-type of data
                    acquisition
                8 - High precision mode;
                    Not possible with Continuous-Mode;
                    Reduces noise feed-back of scsi-transfer.

  OUTPUT:     Blocked mode:
              >=0 - amount of transfered samples
                    CAUTION:
                    The amount of transferred samples must be
                    checked against the requested data length.
                    If the amount of transferred samples is
                    less than the requested amount, an
                    irrecoverable error has occurred during the
                    transfer, which led to a break of the transfer.
                    In the data buffer the correctly transferred
                    data are stored up to the point where the error
                    has occurred!!

              NON-Blocked mode:
                0 - transfer invoked

              Both:
               -1 - no record
               -2 - no buffer type set
               -3 - transfer is active, so can't invoke
                    another transfer !!
               -4 - file transfer already done.
                    reconfigure file buffer settings!

*****************************************/
__LTT2API_IMP long __APIDEC LTTTransfer2Buffers( unsigned long buffer_type,
                                                 unsigned long xfer_mode );


/*****************************************

  FUNCTION: LTTStream2Buffer

  DESCR.:   Transfers the data from the devices
              to the submitted buffer.
              This call initiates the real transfer.
              The transfer can work in BLOCKED or
              NONE_BLOCKED mode.

              BLOCKED:
              The call returns, when the transfer is
              done. This is not possible with the
              STREAM buffer system.

              NONE_BLOCKED:
              The transfer is initiated and the call
              returns immediately. The Transfer must be
              monitored with LTTDataTransferStatus.

  INPUT:    p_buffer:
                Pointer to RAM-Buffer.

              seq_cnt:
                amount of sequences to store;
                must be multiple of 1024

              xfer_mode:
                0 - Blocked mode;
                    Call returns, when data are in buffer.
                1 - NON-Blocked mode;
                    Call initiate transfer and
                    returns imediately.
                    End of transfer can be obtained
                    with 'LTTDataTransferStatus'

  OUTPUT:     Blocked mode:
              >=0 - amount of transfered samples
                    CAUTION:
                    The amount of transferred samples must be
                    checked against the requested data length.
                    If the amount of transferred samples is
                    less than the requested amount, an
                    irrecoverable error has occurred during the
                    transfer, which led to a break of the transfer.
                    In the data buffer the correctly transferred
                    data are stored up to the point where the error
                    has occurred!!

              NON-Blocked mode:
                0 - transfer invoked

              Both:
               -1 - no record
               -2 - STREAM transfer not active
               -3 - transfer is active, so can't invoke
                    another transfer !!
               -4 - sequence count is not valid

*****************************************/
__LTT2API_IMP long __APIDEC LTTStream2Buffer( short *p_buffer,
                                              unsigned long seq_cnt,
                                              unsigned long xfer_mode );


typedef void (*LTTStream2BufferDoneFP) ( short *, long, void * );
/*****************************************

  FUNCTION: LTTStream2BufferCB

  DESCR.:   Transfers the data from the devices
            to the submitted buffer.
            This call initiates the real transfer.
            If the transfer has finished, the callback
            function id called.

  INPUT:    p_buffer:
                Pointer to RAM-Buffer.

            seq_cnt:
              amount of sequences to store;
              must be multiple of 1024

            xfer_flags:
              - continous transfer
              - high-prec transfer

            fp_finished:
              callback function pointer
              
            p_fp_data:
              data pointer, which is paased along to the
              callback function

  OUTPUT:   0 - transfer invoked
           -1 - no record
           -2 - STREAM transfer not active
           -3 - transfer is active, so can't invoke
                another transfer !!
           -4 - sequence count is not valid

*****************************************/
__LTT2API_IMP long __APIDEC LTTStream2BufferCB( short *p_buffer,
                                                unsigned long seq_cnt,
                                                unsigned long xfer_flags,
                                                LTTStream2BufferDoneFP fp_finished,
                                                void *p_fp_data );



/*****************************************

  FUNCTION: LTTDataTransferStatus

  DESCR.:   Monitors the status of the transfer.

              This function is necessary for the
              NONE_BLOCKED Mode of transfer.

  INPUT:    None

  OUTPUT:     0 - nothing TODO
             -1 - waiting for trigger
             -2 - new block available
             -3 - no transfer active
           -255 - error happened

             >0 - transfer finished, gives back
                  amount of transmited samples

                  CAUTION:
                  The amount of transferred samples must be
                  checked against the requested data length.
                  If the amount of transferred samples is
                  less than the requested amount, an
                  irrecoverable error has occurred during the
                  transfer, which led to a break of the transfer.
                  In the data buffer the correctly transferred
                  data are stored up to the point where the error
                  has occurred!!

*****************************************/
__LTT2API_IMP long __APIDEC LTTDataTransferStatus( void );


/*****************************************

  FUNCTION: LTTDataTransferWait

  DESCR.:   Waits until the transfer has
              finished.

              This function is necessary for the
              NONE_BLOCKED Mode of transfer.

  INPUT:    None

  OUTPUT:    -3 - no transfer active
           -255 - error happened

             >0 - transfer finished, gives back
                  amount of transmited samples

                  CAUTION:
                  The amount of transferred samples must be
                  checked against the requested data length.
                  If the amount of transferred samples is
                  less than the requested amount, an
                  irrecoverable error has occurred during the
                  transfer, which led to a break of the transfer.
                  In the data buffer the correctly transferred
                  data are stored up to the point where the error
                  has occurred!!

*****************************************/
__LTT2API_IMP long __APIDEC LTTDataTransferWait( void );


/***************************************************

  FUNCTION: LTTDataTransferBreak

  DESCR.:   Breaks a running transfer.

  INPUT:    None

  OUTPUT:      0 - transfer breaked
              -1 - error happened

 ***************************************************/
__LTT2API_IMP long __APIDEC LTTDataTransferBreak( void );


/*****************************************

  FUNCTION: LTTData_GetCounter

  DESCR.:   Gives back the amount of
              transferred samples.

              This call can be used in
              NONE_BLOCKED Mode of transfer
              to monitor the progress of the
              transfer.

  INPUT:    None

  OUTPUT:   amount of transfered samples

*****************************************/
__LTT2API_IMP long __APIDEC LTTData_GetCounter();


/*****************************************

  FUNCTION: LTTDataTransferCounter

  DESCR.:   Returns the current transfer
            sample counter.

  INPUT:

  OUTPUT:   <sample-count>

*****************************************/
__LTT2API_IMP uint64_t __APIDEC LTTDataTransferCounter();


//== DATA-INFO ===========================

/*****************************************

  FUNCTION: LTTGetChannelIDSequence

  DESCR.:   Gives back channel ID in
              channel sequence

  INPUT:    p_seqlist:
                pointer to list

  OUTPUT:   None

*****************************************/
__LTT2API_IMP void __APIDEC LTTGetChannelIDSequence( unsigned long *p_seqlist );


/*****************************************

  FUNCTION: LTTGetChannelSequenceLength

  DESCR.:   Gives back length of channel
              sequence

  INPUT:    None

  OUTPUT:   Length of channel sequence

*****************************************/
__LTT2API_IMP long __APIDEC LTTGetChannelSequenceLength( void );



//========================================
//  LTT2API-DIGIO
//========================================

/*****************************************

  FUNCTION: LTTDigIO_SetLineDirection

  DESCR.:

  INPUT:    ch_idx:
                DIGIO channel index

              input-mask:
                mask describes which lines
                are configured of input

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTDigIO_SetLineDirection( long ch_idx, unsigned long mask );


/*****************************************

  FUNCTION: LTTDigIO_GetInput

  DESCR.:

  INPUT:    ch_idx:
                DIGIO channel index

              p_data:
                pointer where input-state
                should be stored

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTDigIO_GetInput( long ch_idx, unsigned long *p_data );


/*****************************************

  FUNCTION: LTTDigIO_SetOutput

  DESCR.:

  INPUT:    ch_idx:
                DIGIO channel index

              data:
                new output-state of
                this channel

  OUTPUT:   None

*****************************************/
__LTT2API_IMP long __APIDEC LTTDigIO_SetOutput( long ch_idx, unsigned long data );



#ifdef __cplusplus
}
#endif


#endif


